import click
import os

@click.command()
@click.argument('dir')
def create(dir):
    if os.path.isdir(dir):
        print ('Directory already exists.')
    else:
        os.system('git clone https://github.com/level09/enferno {}'.format(dir))
        ve = os.path.join(dir,'env')
        os.system('virtualenv {}'.format(ve))
        act = os.path.join(ve,'bin','activate')
        pp = os.path.join(ve,'bin','pip')
        req = os.path.join(dir,'requirements.txt')
        os.system('{a} install -r {b}'.format(a=pp,b=req))
        print ("Enferno Framework installed successfully into {}".format(dir))



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()


setup(
    name="Enferno",
    author_email="nidal@level09.com",
    description="Enferno framework CLI tool, helps you create and setup your Enferno app quickly.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/level09/enferno-cli",
    python_requires='>=3.5',
    license='MIT',
    version='0.2',
    py_modules=['enferno'],
    install_requires=[
        'Click',
    ],
    entry_points='''
        [console_scripts]
        enferno=enferno:create
    ''',
)
